/**************************************************************************
date: 1/25/97
file: picdrv.hpp

title:	PICDRV - Programmable Interrupt Controller Driver class    
  
public:
	Install(UINT unIRQ, INTHANDLER pfnIntHandler)
	EndOfInterrupt()
	Chain()
	Restore()

description:
	FUNCTIONS MUST BE RUN WITH INTERRUPTS OFF!

history:  AJM initial version
**************************************************************************/
#ifndef PICDRV_HPP
#define PICDRV_HPP

#pragma check_stack( off )
#pragma check_pointer( off )

#include "loctypes.h"	// local types
#include "dospc.h"	// non-standard DOS functions

class PICDRV {
private:
	// Constants
	enum {
		PIC1VECTOR  = 8,    // start location for IRQ vectors on PIC1
		PIC2VECTOR  = 104,  // start location for IRQ vectors on PIC2
		PIC1 	    = 0x20,    
		PIC2	    = 0xa0,
		PIC1MASKREG = 0x21,
		PIC2MASKREG = 0xa1,
		PIC1LASTIRQ = 7,
		PIC2LASTIRQ = 15,
		EOI	    = 0x20	// End of Interrupt signal
	};

	// Data Members
	UCHAR		unIRQ;		// used as short to save stack space
	UCHAR		eWasEnabled;	// used as BOOL to save stack space
	INTHANDLER	pfnOldIntHandler;

	// Auxillary Functions 
	IOADDRESS	GetPicMaskReg(UINT unIRQNumber);
	UINT		GetPicVector(UINT unIRQNumber);
	UINT		GetPicMask(UINT unIRQNumber);

public:
	BOOL	Install(UINT unIRQNumber, INTHANDLER pfnIntHandler);

	VOID	EndOfInterrupt() {
		if (unIRQ > PIC1LASTIRQ) {
			outp(PIC2, EOI);	// signal EOI to 2nd PIC
		}
		outp(PIC1, EOI);	// signal EOI to 1st PIC
	}

	VOID	Chain() {
		if (eWasEnabled) {
			_chain_intr((INTHANDLER) pfnOldIntHandler);
		}
	}

	VOID	Restore();

};
#endif // picdrv.hpp
