/****************************************************************************
Copyright 1997 Anthony Monteiro

Date: 11/19/97
File: xpdrbase.cpp
Description:	TRANSPONDER ABSTRACT BASE CLASS

	This class is the base class for all transponders.

	public:
		static TRANSPONDER* NewInstance(const TRANSPONDERPARAMS& Params)

		DOUBLE GetInputFreq() const
		DOUBLE GetOutputFreq() const

		MODULATION GetInputMode() const
		MODULATION GetOutputMode() const

		virtual VOID SetInputFreq(Double dFreq)	= 0
		virtual VOID SetOutputFreq(DOUBLE dFreq) = 0

		virtual VOID SetInputMode(MODULATION eMode) = 0;
		virtual VOID SetOutputMode(MODULATION eMode) = 0;

		virtual ~TRANSPONDER()

History:
	11/19/97 Release 1.0
*****************************************************************************/
#include "xpdrbase.hpp"

// Derived classes
#include "xpdrfxd.hpp"	// fixed-frequency ("digital") transponder
#include "xpdrlin.hpp"	// linear transponder
#include "xpdrinv.hpp"	// inverting linear transponder


TRANSPONDER* TRANSPONDER::NewInstance(const TRANSPONDERPARAMS& Params) {

	TRANSPONDER* pTransponder;

	switch(Params.eType) {
	case TRANSPONDERTYPE_NONINVERTING:
		pTransponder = new NONINVERTINGTRANSPONDER(Params);
		break;

	case TRANSPONDERTYPE_INVERTING:
		pTransponder = new INVERTINGTRANSPONDER(Params);
		break;

	default:
		// Fixed frequency or NULL Transponder 
		pTransponder = new FIXEDTRANSPONDER(Params);
		break;
	}

	return pTransponder;
}
// end xpdrbase.cpp
